pub fn deploy_program(
log_collector: Option<Rc<RefCell<LogCollector>>>,
program_cache_for_tx: &mut ProgramCacheForTx<'_>,
program_runtime_environment: ProgramRuntimeEnvironment,
program_id: &Pubkey,
loader_key: &Pubkey,
account_size: usize,
programdata: &[u8],
deployment_slot: Slot,
) -> Result<LoadProgramMetrics, InstructionError>Expand description
Directly deploy a program using a provided invoke context. This function should only be invoked from the runtime, since it does not provide any account loads or checks.